| Title: | A Friendly Package Manager |
|---|---|
| Description: | Manage project dependencies from your DESCRIPTION file. Create a reproducible virtual environment with minimal additional files in your project. Provides tools to add, remove, and update dependencies as well as install existing dependencies with a single function. |
| Authors: | Andrew Kane [aut, cre] |
| Maintainer: | Andrew Kane <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.5.5 |
| Built: | 2026-06-07 10:35:18 UTC |
| Source: | https://github.com/ankane/jetpack |
Add a package
add(packages, remotes = c())add(packages, remotes = c())
packages |
Packages to add |
remotes |
Remotes to add |
No return value
## Not run: jetpack::add("randomForest") jetpack::add(c("randomForest", "DBI")) jetpack::add("[email protected]") jetpack::add("plyr", remote="hadley/plyr") jetpack::add("plyr", remote="local::/path/to/plyr") ## End(Not run)## Not run: jetpack::add("randomForest") jetpack::add(c("randomForest", "DBI")) jetpack::add("[email protected]") jetpack::add("plyr", remote="hadley/plyr") jetpack::add("plyr", remote="local::/path/to/plyr") ## End(Not run)
Check that all dependencies are installed
check()check()
TRUE if all dependencies are installed, FALSE otherwise, invisibly
## Not run: jetpack::check() ## End(Not run)## Not run: jetpack::check() ## End(Not run)
Install the command line interface
cli(file = NULL)cli(file = NULL)
file |
The file to create |
No return value
## Not run: jetpack::cli() ## End(Not run)## Not run: jetpack::cli() ## End(Not run)
Set up Jetpack
init()init()
No return value
## Not run: jetpack::init() ## End(Not run)## Not run: jetpack::init() ## End(Not run)
Install packages for a project
install(deployment = FALSE)install(deployment = FALSE)
deployment |
Use deployment mode |
No return value
## Not run: jetpack::install() ## End(Not run)## Not run: jetpack::install() ## End(Not run)
Show outdated packages
outdated()outdated()
No return value
## Not run: jetpack::outdated() ## End(Not run)## Not run: jetpack::outdated() ## End(Not run)
Remove a package
remove(packages, remotes = c())remove(packages, remotes = c())
packages |
Packages to remove |
remotes |
Remotes to remove |
No return value
## Not run: jetpack::remove("randomForest") jetpack::remove(c("randomForest", "DBI")) jetpack::remove("plyr", remote="hadley/plyr") ## End(Not run)## Not run: jetpack::remove("randomForest") jetpack::remove(c("randomForest", "DBI")) jetpack::remove("plyr", remote="hadley/plyr") ## End(Not run)
Update a package
update(packages = c(), remotes = c())update(packages = c(), remotes = c())
packages |
Packages to update |
remotes |
Remotes to update |
No return value
## Not run: jetpack::update("randomForest") jetpack::update(c("randomForest", "DBI")) jetpack::update() ## End(Not run)## Not run: jetpack::update("randomForest") jetpack::update(c("randomForest", "DBI")) jetpack::update() ## End(Not run)